@@ -70,17 +70,15 @@ class Kernel( object ):
             raise RuntimeError( """Must have same number of priors as parameters""" )
         self.params = params
         self.param_priors = param_priors
-        has_derivative_class = False
         try:
+            # if it has a derivative class, create derivative object for each parameter
             self.__class__.Derivative
-            has_derivative_class = True
+            self.derivatives = [
+                self.__class__.Derivative( self, i )
+                for i in xrange( len(params) )
+            ]
         except:
             pass
-        if has_derivative_class:
-            self.derivatives = [
-                    self.__class__.Derivative( self, i )
-                    for i in xrange( len(params) )
-            ]
 
 
     def __mul__(self, k_rhs):
@@ -108,6 +106,7 @@ class Kernel( object ):
         for i, p in enumerate( new_params ):
             self.params[i] = p
 
+
     def supports( self, p ):
         """
         True if all the parameters, p, are in the support of the kernel's priors
@@ -119,11 +118,13 @@ class Kernel( object ):
             if None != prior and not prior.supports( p1 ): return False
         return True
 
+
     def __str__( self ):
         """String representation of kernel"""
         raise RuntimeError( """%s.__str__() Should have been implemented """
                 """in base class""" % str(self.__class__) )
 
+
     def __call__( self, x1, x2, identical = False ):
         """Returns value of kernel for the specified data points
 
@@ -131,6 +132,7 @@ class Kernel( object ):
         """
         raise RuntimeError, 'Kernel.__call__() should be implemented in sub-class'
 
+
     def derivative_wrt_param( self, i ):
         """
         Returns the derivative of the kernel with respect to the i'th parameter.
