@@ -211,9 +211,9 @@ def plot_roc_points(rocs, **plot_kwds):
     """
     Plots TPR versus FPR for the ROCs in rocs. Adds points at (0,0) and (1,1).
 
-    @arg rocs: A sequence of ROCs.
-    @arg **plot_kwds: All extra keyword arguments are passed to the pylab.plot call.
-    @return: The result of pylab.plot call.
+    :param rocs: A sequence of ROCs.
+    :param plot_kwds: All extra keyword arguments are passed to the pylab.plot call.
+    :returns: The result of pylab.plot call.
     """
     from pylab import plot
     return plot(
@@ -227,9 +227,9 @@ def plot_precision_versus_recall(rocs, **plot_kwds):
     """
     Plots precision versus recall for the ROCs in rocs. Adds points at (0,1) and (1,0).
 
-    @arg rocs: A sequence of ROCs.
-    @arg **plot_kwds: All extra keyword arguments are passed to the pylab.plot call.
-    @return: The result of pylab.plot call.
+    :param rocs: A sequence of ROCs.
+    :param plot_kwds: All extra keyword arguments are passed to the pylab.plot call.
+    :returns: The result of pylab.plot call.
     """
     from pylab import plot
     points = [(roc.recall(), roc.precision()) for roc in rocs]
@@ -245,11 +245,11 @@ def plot_precision_recall(roc_thresholds, recall_plot_kwds={}, precision_plot_kw
     """
     Plots a precision-recall curve for the given ROCs.
 
-    @arg roc_thresholds: A sequence of tuples (ROC, threshold).
-    @arg recall_plot_kwds: Passed to the pylab.plot call for the recall.
-    @arg precision_plot_kwds: Passed to the pylab.plot call for the precision.
-    @arg plot_fn: Function used to plot. Use pylab.semilogx for log scale threshold axis.
-    @return: The result of 2 pylab.plot calls as a tuple (recall, precision).
+    :param roc_thresholds: A sequence of tuples (ROC, threshold).
+    :param recall_plot_kwds: Passed to the pylab.plot call for the recall.
+    :param precision_plot_kwds: Passed to the pylab.plot call for the precision.
+    :param plot_fn: Function used to plot. Use pylab.semilogx for log scale threshold axis.
+    :returns: The result of 2 pylab.plot calls as a tuple (recall, precision).
     """
     if None == plot_fn:
         from pylab import plot
@@ -281,11 +281,11 @@ def plot_precision_recall(roc_thresholds, recall_plot_kwds={}, precision_plot_kw
 
 def area_under_curve(rocs, include_0_0=True, include_1_1=True):
     """
-    @arg rocs: The ROC points.
-    @arg include_0_0: True to include extra point for origin of ROC curve.
-    @arg include_1_1: True to include extra point at (1,1) in ROC curve.
+    :param rocs: The ROC points.
+    :param include_0_0: True to include extra point for origin of ROC curve.
+    :param include_1_1: True to include extra point at (1,1) in ROC curve.
 
-    @return: The area under the ROC curve given by the ROC points.
+    :returns: The area under the ROC curve given by the ROC points.
     """
     x_axis = []
     y_axis = []
@@ -347,7 +347,7 @@ def count_threshold_classifications(thresholds, value):
     """
     Take a list of thresholds (in sorted order) and count how many would be classified positive and negative at the given value.
 
-    @return: (num_positive, num_negative).
+    :returns: (num_positive, num_negative).
     """
     from bisect import bisect_right
     idx = bisect_right(thresholds, value)
@@ -365,7 +365,7 @@ def roc_for_threshold(positive_thresholds, negative_thresholds, value):
 
 
 def make_roc_from_threshold_fn(positive_thresholds, negative_thresholds):
-    "@return: A function that calculates a ROC point given a threshold."
+    ":returns: A function that calculates a ROC point given a threshold."
     def local_roc_for_threshold(value):
         return roc_for_threshold(positive_thresholds, negative_thresholds, value)
     return local_roc_for_threshold
@@ -376,7 +376,7 @@ def rocs_from_thresholds(positive_thresholds, negative_thresholds, num_points=32
     Takes 2 sorted lists: one list is of the thresholds required to classify the positive examples as positive
     and the other list is of the thresholds required to classify the negative examples as positive.
 
-    @return: A list of ROC points.
+    :returns: A list of ROC points.
     """
     min_threshold = min(positive_thresholds[0], negative_thresholds[0])
     max_threshold = max(positive_thresholds[-1], negative_thresholds[-1])
@@ -391,7 +391,7 @@ def pick_roc_thresholds(roc_for_threshold_fn, min_threshold, max_threshold, num_
     """
     Tries to pick thresholds to give a smooth ROC curve.
 
-    @return: A list of (roc point, threshold) tuples.
+    :returns: A list of (roc point, threshold) tuples.
     """
     def add_threshold(threshold):
         "Calculate the ROC point and add to list."
@@ -421,7 +421,7 @@ def create_rocs_from_thresholds(positive_thresholds, negative_thresholds, num_po
     Takes 2 sorted lists: one list is of the thresholds required to classify the positive examples as positive
     and the other list is of the thresholds required to classify the negative examples as positive.
 
-    @return: A list of tuples (ROC point, threshold).
+    :returns: A list of tuples (ROC point, threshold).
     """
     return pick_roc_thresholds(
                 make_roc_from_threshold_fn(positive_thresholds, negative_thresholds),
@@ -436,7 +436,7 @@ def picked_rocs_from_thresholds(positive_thresholds, negative_thresholds, num_po
     Takes 2 sorted lists: one list is of the thresholds required to classify the positive examples as positive
     and the other list is of the thresholds required to classify the negative examples as positive.
 
-    @return: A list of ROC points.
+    :returns: A list of ROC points.
     """
     return [roc for roc, t in create_rocs_from_thresholds(positive_thresholds, negative_thresholds, num_points=num_points)]
 
